@@ -8,6 +8,10 @@
 #define sv_derived_from_pvn(sv, name, namelen, flags) sv_derived_from(sv, name)
 #endif
 
+#ifndef sv_dup_inc
+#define sv_dup_inc(sv, param) SvREFCNT_inc(sv_dup(sv, param))
+#endif
+
 SV* S_clone_value(pTHX_ SV* original) {
 	dSP;
 	PUSHSTACKi(PERLSI_MAGIC);
